from __future__ import annotations
from pathlib import Path

try:
    # Version generated by setuptools_scm during build
    from ._version import __version__
except ImportError:
    __version__ = None

# Top-level API (available directly from "zut" namespace). Does not require any dependency.
from .colors import Colors
from .commands import ArgumentManager, ArgumentResource, ArgumentParser, add_func_command, add_module_command, add_package_commands, main, get_help_text, get_description_text, get_module_version
from .config import get_config, ExtendedConfigParser
from .csv import get_csv_headers, get_default_csv_delimiter
from .datetime import now_aware, make_aware, make_naive, is_aware
from .db import DbAdapter, PgAdapter, Pg2Adapter, MssqlAdapter, get_db_adapter, get_db_adapter_with_schema_and_table, pg_notice_handler, Pg2NoticeHandler
from .defaults import enable_default_locale
from .filesh import configure_smb_credentials  # other functions should be called directly with the module, e.g. `from zut import filesh`, then `filesh.open_file(...)`
from .http import JSONApiClient, ApiClientError
from .inout import out_file, out_table, in_table, transfer_table, OutFile, OutTable, OutTabulate, OutCsv, OutExcel, OutDb, InTable, InCsv, InExcel, InDb, Row, normalize_inout, register_out_file_handler, register_out_table_handler, register_in_table_handler
from .json import ExtendedJSONDecoder, ExtendedJSONEncoder
from .logging import configure_logging, get_logging_dict_config
from .numeric import human_bytes, parse_decimal
from .process import get_exit_code, check_completed_subprocess
from .text import StringFilter, ValueString, slugify, slugify_snake, remove_whitespaces, remove_consecutive_whitespaces, skip_bom, build_url, build_netloc
from .types import get_iterable_element_type, is_iterable_of
from .unittest import StartTestProgram

ZUT_ROOT = Path(__file__).parent
""" Root directory of `zut` library """

# NOTE: Inner API: the following modules require extra dependencies.
# zut.django
# zut.excel
